@@ -1,4 +1,3 @@
-import { debounce } from 'lodash';
 import {
   createContext,
   Dispatch,
@@ -28,24 +27,19 @@ import { config, getDataSourceSrv } from '@grafana/runtime';
 import { PopoverContent } from '@grafana/ui';
 
 import { checkLogsError, checkLogsSampled, downloadLogs as download, DownloadFormat } from '../../utils';
+import { getFieldSelectorState } from '../fieldSelector/fieldSelectorUtils';
 import { getDisplayedFieldsForLogs } from '../otel/formats';
 
+import { getDefaultDetailsMode, getDetailsWidth } from './LogDetailsContext';
 import { LogLineTimestampResolution } from './LogLine';
-import { LogLineDetailsMode } from './LogLineDetails';
 import { GetRowContextQueryFn, LogLineMenuCustomItem } from './LogLineMenu';
 import { LogListOptions, LogListFontSize } from './LogList';
-import { reportInteractionOnce } from './analytics';
+import { collectInsights } from './analytics';
 import { LogListModel } from './processing';
-import { getScrollbarWidth, LOG_LIST_CONTROLS_WIDTH, LOG_LIST_MIN_WIDTH } from './virtualization';
 
 export interface LogListContextData extends Omit<Props, 'containerElement' | 'logs' | 'logsMeta' | 'showControls'> {
-  closeDetails: () => void;
   controlsExpanded: boolean;
-  detailsDisplayed: (log: LogListModel) => boolean;
-  detailsMode: LogLineDetailsMode;
-  detailsWidth: number;
   downloadLogs: (format: DownloadFormat) => void;
-  enableLogDetails: boolean;
   filterLevels: LogLevel[];
   forceEscape: boolean;
   hasLogsWithErrors?: boolean;
@@ -54,8 +48,6 @@ export interface LogListContextData extends Omit<Props, 'containerElement' | 'lo
   logLineMenuCustomItems?: LogLineMenuCustomItem[];
   setControlsExpanded: (expanded: boolean) => void;
   setDedupStrategy: (dedupStrategy: LogsDedupStrategy) => void;
-  setDetailsMode: (mode: LogLineDetailsMode) => void;
-  setDetailsWidth: (width: number) => void;
   setFilterLevels: (filterLevels: LogLevel[]) => void;
   setFontSize: (size: LogListFontSize) => void;
   setForceEscape: (forceEscape: boolean) => void;
@@ -68,24 +60,17 @@ export interface LogListContextData extends Omit<Props, 'containerElement' | 'lo
   setSortOrder: (sortOrder: LogsSortOrder) => void;
   setTimestampResolution: (format: LogLineTimestampResolution) => void;
   setWrapLogMessage: (showTime: boolean) => void;
-  showDetails: LogListModel[];
   timestampResolution: LogLineTimestampResolution;
-  toggleDetails: (log: LogListModel) => void;
   isAssistantAvailable: boolean;
   openAssistantByLog: ((log: LogListModel) => void) | undefined;
 }
 
 export const LogListContext = createContext<LogListContextData>({
   app: CoreApp.Unknown,
-  closeDetails: () => {},
   controlsExpanded: false,
   dedupStrategy: LogsDedupStrategy.none,
-  detailsDisplayed: () => false,
-  detailsMode: 'sidebar',
-  detailsWidth: 0,
   displayedFields: [],
   downloadLogs: () => {},
-  enableLogDetails: false,
   filterLevels: [],
   forceEscape: false,
   fontSize: 'default',
@@ -93,8 +78,6 @@ export const LogListContext = createContext<LogListContextData>({
   noInteractions: false,
   setControlsExpanded: () => {},
   setDedupStrategy: () => {},
-  setDetailsMode: () => {},
-  setDetailsWidth: () => {},
   setFilterLevels: () => {},
   setFontSize: () => {},
   setForceEscape: () => {},
@@ -107,12 +90,10 @@ export const LogListContext = createContext<LogListContextData>({
   setSyntaxHighlighting: () => {},
   setTimestampResolution: () => {},
   setWrapLogMessage: () => {},
-  showDetails: [],
   showTime: true,
   sortOrder: LogsSortOrder.Ascending,
   syntaxHighlighting: true,
   timestampResolution: 'ns',
-  toggleDetails: () => {},
   wrapLogMessage: false,
   isAssistantAvailable: false,
   openAssistantByLog: () => {},
@@ -156,10 +137,8 @@ export interface Props {
   children?: ReactNode;
   // Only ControlledLogRows can send an undefined containerElement. See LogList.tsx
   containerElement?: HTMLDivElement;
-  detailsMode?: LogLineDetailsMode;
   dedupStrategy: LogsDedupStrategy;
   displayedFields: string[];
-  enableLogDetails: boolean;
   filterLevels?: LogLevel[];
   fontSize: LogListFontSize;
   getRowContextQuery?: GetRowContextQueryFn;
@@ -201,11 +180,7 @@ export const LogListContextProvider = ({
   app,
   children,
   containerElement,
-  enableLogDetails,
   logOptionsStorageKey,
-  detailsMode: detailsModeProp = logOptionsStorageKey
-    ? (store.get(`${logOptionsStorageKey}.detailsMode`) ?? getDefaultDetailsMode(containerElement))
-    : getDefaultDetailsMode(containerElement),
   dedupStrategy,
   displayedFields,
   filterLevels,
@@ -258,14 +233,7 @@ export const LogListContextProvider = ({
     syntaxHighlighting,
     timestampResolution,
   });
-  const [showDetails, setShowDetails] = useState<LogListModel[]>([]);
-  const [detailsWidth, setDetailsWidthState] = useState(
-    getDetailsWidth(containerElement, logOptionsStorageKey, undefined, detailsModeProp, showControls)
-  );
-  const [detailsMode, setDetailsMode] = useState<LogLineDetailsMode>(
-    detailsModeProp ?? getDefaultDetailsMode(containerElement)
-  );
-  const [isAssistantAvailable, openAssistant] = useAssistant();
+  const { isAvailable: isAssistantAvailable, openAssistant } = useAssistant();
   const [prettifyJSON, setPrettifyJSONState] = useState(prettifyJSONProp);
   const [wrapLogMessage, setWrapLogMessageState] = useState(wrapLogMessageProp);
 
@@ -273,17 +241,20 @@ export const LogListContextProvider = ({
     if (noInteractions) {
       return;
     }
-    reportInteractionOnce(`logs_log_list_${app}_logs_displayed`, {
+    collectInsights(logs, app, {
       dedupStrategy,
       fontSize,
       forceEscape: logListState.forceEscape,
+      fieldSelectorOpen: getFieldSelectorState(logOptionsStorageKey),
       showTime,
       showUniqueLabels,
       syntaxHighlighting,
       wrapLogMessage,
       prettifyJSON,
-      detailsWidth,
-      detailsMode,
+      detailsWidth: getDetailsWidth(containerElement, logOptionsStorageKey),
+      detailsMode: logOptionsStorageKey
+        ? (store.get(`${logOptionsStorageKey}.detailsMode`) ?? getDefaultDetailsMode(containerElement))
+        : getDefaultDetailsMode(containerElement),
       withDisplayedFields: displayedFields.length > 0,
       timestampResolution: logListState.timestampResolution,
     });
@@ -346,13 +317,6 @@ export const LogListContextProvider = ({
     });
   }, [filterLevels]);
 
-  // Sync details mode
-  useEffect(() => {
-    if (detailsModeProp) {
-      setDetailsMode(detailsModeProp);
-    }
-  }, [detailsModeProp]);
-
   // Sync font size
   useEffect(() => {
     setLogListState((logListState) => ({ ...logListState, fontSize }));
@@ -365,39 +329,6 @@ export const LogListContextProvider = ({
     }
   }, [logListState, pinnedLogs]);
 
-  // Sync show details
-  useEffect(() => {
-    if (!showDetails.length) {
-      return;
-    }
-    const newShowDetails = showDetails.filter(
-      (expandedLog) => logs.findIndex((log) => log.uid === expandedLog.uid) >= 0
-    );
-    if (newShowDetails.length !== showDetails.length) {
-      setShowDetails(newShowDetails);
-    }
-  }, [logs, showDetails]);
-
-  // Sync log details inline and sidebar width
-  useEffect(() => {
-    setDetailsWidthState(getDetailsWidth(containerElement, logOptionsStorageKey, undefined, detailsMode, showControls));
-  }, [containerElement, detailsMode, logOptionsStorageKey, showControls]);
-
-  // Sync log details width
-  useEffect(() => {
-    if (!containerElement) {
-      return;
-    }
-    const handleResize = debounce(() => {
-      setDetailsWidthState((detailsWidth) =>
-        getDetailsWidth(containerElement, logOptionsStorageKey, detailsWidth, detailsMode, showControls)
-      );
-    }, 50);
-    const observer = new ResizeObserver(() => handleResize());
-    observer.observe(containerElement);
-    return () => observer.disconnect();
-  }, [containerElement, detailsMode, logOptionsStorageKey, showControls]);
-
   // Sync prettifyJSON
   useEffect(() => {
     if (prettifyJSONProp !== undefined) {
@@ -432,11 +363,6 @@ export const LogListContextProvider = ({
   // If the user has a large viewport, show the expanded state by default
   const [controlsExpanded, setControlsExpanded] = useState<boolean>(controlsExpandedFromStore);
 
-  const detailsDisplayed = useCallback(
-    (log: LogListModel) => !!showDetails.find((shownLog) => shownLog.uid === log.uid),
-    [showDetails]
-  );
-
   const setDedupStrategy = useCallback(
     (dedupStrategy: LogsDedupStrategy) => {
       setLogListState({ ...logListState, dedupStrategy });
@@ -557,48 +483,9 @@ export const LogListContextProvider = ({
         logListState.filterLevels.length === 0
           ? logs
           : logs.filter((log) => logListState.filterLevels.includes(log.logLevel));
-      download(format, filteredLogs, logsMeta);
+      download(format, filteredLogs, logsMeta, displayedFields);
     },
-    [logListState.filterLevels, logs, logsMeta]
-  );
-
-  const closeDetails = useCallback(() => {
-    showDetails.forEach((log) => removeDetailsScrollPosition(log));
-    setShowDetails([]);
-  }, [showDetails]);
-
-  const toggleDetails = useCallback(
-    (log: LogListModel) => {
-      if (!enableLogDetails) {
-        return;
-      }
-      const found = showDetails.find((stateLog) => stateLog === log || stateLog.uid === log.uid);
-      if (found) {
-        removeDetailsScrollPosition(found);
-        setShowDetails(showDetails.filter((stateLog) => stateLog !== log && stateLog.uid !== log.uid));
-      } else {
-        // Supporting one displayed details for now
-        setShowDetails([...showDetails, log]);
-      }
-    },
-    [enableLogDetails, showDetails]
-  );
-
-  const setDetailsWidth = useCallback(
-    (width: number) => {
-      if (!logOptionsStorageKey || !containerElement) {
-        return;
-      }
-
-      const maxWidth = containerElement.clientWidth - LOG_LIST_MIN_WIDTH;
-      if (width > maxWidth) {
-        return;
-      }
-
-      store.set(`${logOptionsStorageKey}.detailsWidth`, width);
-      setDetailsWidthState(width);
-    },
-    [containerElement, logOptionsStorageKey]
+    [displayedFields, logListState.filterLevels, logs, logsMeta]
   );
 
   const setTimestampResolution = useCallback(
@@ -632,15 +519,10 @@ export const LogListContextProvider = ({
     <LogListContext.Provider
       value={{
         app,
-        closeDetails,
         controlsExpanded,
-        detailsDisplayed,
         dedupStrategy: logListState.dedupStrategy,
-        detailsMode,
-        detailsWidth,
         displayedFields,
         downloadLogs,
-        enableLogDetails,
         filterLevels: logListState.filterLevels,
         fontSize: logListState.fontSize,
         forceEscape: logListState.forceEscape,
@@ -670,8 +552,6 @@ export const LogListContextProvider = ({
         prettifyJSON,
         setControlsExpanded,
         setDedupStrategy,
-        setDetailsMode,
-        setDetailsWidth,
         setDisplayedFields,
         setFilterLevels,
         setFontSize,
@@ -685,13 +565,11 @@ export const LogListContextProvider = ({
         setSyntaxHighlighting,
         setTimestampResolution,
         setWrapLogMessage,
-        showDetails,
         showTime: logListState.showTime,
         showUniqueLabels: logListState.showUniqueLabels,
         sortOrder: logListState.sortOrder,
         syntaxHighlighting: logListState.syntaxHighlighting,
         timestampResolution: logListState.timestampResolution,
-        toggleDetails,
         wrapLogMessage,
         isAssistantAvailable,
         openAssistantByLog,
@@ -715,50 +593,6 @@ export function isDedupStrategy(value: unknown): value is LogsDedupStrategy {
   );
 }
 
-// Only ControlledLogRows can send an undefined containerElement. See LogList.tsx
-function getDetailsWidth(
-  containerElement: HTMLDivElement | undefined,
-  logOptionsStorageKey?: string,
-  currentWidth?: number,
-  detailsMode: LogLineDetailsMode = 'sidebar',
-  showControls?: boolean
-) {
-  if (!containerElement) {
-    return 0;
-  }
-  if (detailsMode === 'inline') {
-    return containerElement.clientWidth - getScrollbarWidth() - (showControls ? LOG_LIST_CONTROLS_WIDTH : 0);
-  }
-  const defaultWidth = containerElement.clientWidth * 0.4;
-  const detailsWidth =
-    currentWidth ||
-    (logOptionsStorageKey
-      ? parseInt(store.get(`${logOptionsStorageKey}.detailsWidth`) ?? defaultWidth, 10)
-      : defaultWidth);
-
-  const maxWidth = containerElement.clientWidth - LOG_LIST_MIN_WIDTH;
-
-  // The user might have resized the screen.
-  if (detailsWidth >= containerElement.clientWidth || detailsWidth > maxWidth) {
-    return currentWidth ?? defaultWidth;
-  }
-  return detailsWidth;
-}
-
-const detailsScrollMap = new Map<string, number>();
-
-export function saveDetailsScrollPosition(log: LogListModel, position: number) {
-  detailsScrollMap.set(log.uid, position);
-}
-
-export function getDetailsScrollPosition(log: LogListModel) {
-  return detailsScrollMap.get(log.uid) ?? 0;
-}
-
-export function removeDetailsScrollPosition(log: LogListModel) {
-  detailsScrollMap.delete(log.uid);
-}
-
 async function handleOpenAssistant(openAssistant: (props: OpenAssistantProps) => void, log: LogListModel) {
   const datasource = await getDataSourceSrv().get(log.datasourceUid);
   const context = [];
@@ -791,11 +625,6 @@ ${log.entry.replaceAll('`', '\\`')}
   });
 }
 
-export function getDefaultDetailsMode(container: HTMLDivElement | undefined): LogLineDetailsMode {
-  const width = container?.clientWidth ?? window.innerWidth;
-  return width > 1440 ? 'sidebar' : 'inline';
-}
-
 export function getDefaultControlsExpandedMode(container: HTMLDivElement | null): boolean {
   const width = container?.clientWidth ?? window.innerWidth;
   return width > 1200;
